<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Scope;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Domain\Speaker\Handlers\CreateSpeaker;
use EventPortal\Domain\Speaker\Handlers\UpdateSpeaker;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\User\Models\User;
use EventPortal\Enums\InertiaMethod;

Form::make('speaker.create')
    ->addSaveHandler(new CreateModel)
    ->addSaveHandler(new CreateSpeaker)
    ->model(new User)
    ->addFields(static function () {
        return [
            Section::make()->fields([
                Text::make('First name')->rules(['required']),
                Text::make('Last name')->rules(['required']),
                Select::make('Speaker Type')
                    ->name('type')
                    ->placeholder('Please select speaker type')
                    ->options([
                        Option::make('Sales HCP'),
                        Option::make('Other'),
                    ]),
                Text::make('Email')->rules(['required', 'email', 'unique:users,email']),
                Text::make('Profession'),
                Text::make('Telephone number'),
            ]),
        ];
    })
    ->addActions(static function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.index'),
            Button::make('Add Speaker')
                ->method(InertiaMethod::POST())
                ->route('admin.speaker.store'),
        ];
    });

Form::make('speaker.edit')
    ->addSaveHandler(new UpdateModel)
    ->addSaveHandler(new UpdateSpeaker)
    ->addActions(static function (Speaker $speaker) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.index'),
            Button::make('Update Speaker')
                ->method(InertiaMethod::POST())
                ->route('admin.speaker.update', ['speaker' => $speaker]),
        ];
    });

Form::make('speaker.show')
    ->addFields(static function () {
        return [
            Section::make()->fields([
                Display::make('First name')->scopeTo('user'),
                Display::make('Last name')->scopeTo('user'),
                Display::make('Email')->scopeTo('user'),
                Display::make('Profession'),
                Display::make('Telephone number'),
            ]),
        ];
    })
    ->addActions(static function (Speaker $speaker) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.index'),
            Button::make('Edit Speaker')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.edit', ['speaker' => $speaker]),
        ];
    });

Form::make('speaker.edit')
    ->addFields(static function () {
        return [
            Section::make()->fields([
                Scope::make('user')->fields([
                    Text::make('First name')->rules(['required']),
                    Text::make('Last name')->rules(['required']),
                ]),
                Select::make('Speaker Type')
                    ->name('type')
                    ->placeholder('Please select speaker type')
                    ->options([
                        Option::make('Sales HCP'),
                        Option::make('Other'),
                    ]),
                Text::make('Email')
                    ->scopeTo('user')
                    ->rules(['required', 'email']),
                Text::make('Profession'),
                Text::make('Telephone number'),
            ]),
        ];
    });
