<?php

namespace EventPortal\Domain\Speaker\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Domain\Table\Concerns\HasTable;
use EventPortal\Domain\User\Models\User;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Str;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Speaker extends Model implements AuditableInterface
{
    use HasTable, AddToFillable, AddToCasts, Auditable;

    public const KEY = 'speaker';

    /** @var array<string> */
    public $with = [
        'user',
    ];

    /** @var array<string> */
    protected $fillable = [
        'profession',
        'telephone_number',
        'user_id',
    ];

    public function user(): BelongsTo
    {
        return $this->belongsTo(config('auth.providers.users.model'), 'user_id');
    }

    public function getNameAttribute(): string
    {
        return Str::of($this->user->first_name)->append(' ')->append($this->user->last_name);
    }

    public function scopeByUser(Builder $query, User $user): Builder
    {
        return $query->where('user_id', $user->id);
    }
}
