<?php

namespace EventPortal\Domain\Table;

use EventPortal\Domain\Component\Column\ActionColumn;
use Illuminate\Contracts\Pagination\LengthAwarePaginator;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Arr;
use Illuminate\Support\Collection;

class Table
{
    /** @var array */
    public $columns = [];

    /** @var array */
    public $allColumns = [];

    /** @var array */
    public $data = [];

    public $action;

    /** @var array */
    public $context = [];

    /** @var array */
    public $globalActions = [];

    /** @var array */
    public $filterFields = [];

    public $metadata = [
        'filters' => [],
        'sortBy' => [],
        'totalItems' => 0,
        'pageCount' => 0,
        'pageNum' => 1,
        'pageSize' => 0,
        'columns' => [],
    ];

    public static function make(): self
    {
        return new self();
    }

    public function defaultPageSize(string $pageSize): self
    {
        $this->metadata['pageSize'] = $pageSize;

        return $this;
    }

    public function withColumns(Collection $columns): self
    {
        $this->columns = $columns->values()->toArray();

        $this->columns[] = ActionColumn::make('action');

        $this->metadata['columns'] = Arr::pluck($this->columns, 'name');

        return $this;
    }

    public function withAllColumns(Collection $columns): self
    {
        $this->allColumns = $columns->values()->toArray();

        return $this;
    }

    public function withFiltersFields(Collection $filterFields): self
    {
        $this->filterFields = $filterFields->values()->toArray();

        return $this;
    }

    public function withAction(?callable $action): self
    {
        if ($action !== null) {
            $this->action = $action;
        }

        return $this;
    }

    public function withContext(?array $models): self
    {
        if ($models !== []) {
            $this->context = $models;
        }

        return $this;
    }

    public function currentFilters(Collection $filters): self
    {
        $this->metadata['filters'] = $filters
            ->map(static function ($value, $key) {
                return [
                    'id' => $key,
                    'value' => $value,
                ];
            })
            ->values()
            ->toArray();

        return $this;
    }

    public function currentQuery(?string $query): self
    {
        if ($query !== null) {
            $this->metadata['query'] = $query;
        }

        return $this;
    }

    public function withGlobalActions(Collection $actions): self
    {
        $this->globalActions = $actions;

        return $this;
    }

    public function withData(LengthAwarePaginator $data, Collection $columns): self
    {
        $this->metadata['totalItems'] = $data->total();
        $this->metadata['pageCount'] = $data->lastPage();
        $this->metadata['pageNum'] = $data->currentPage();

        $data
            ->map(function (Model $model) use ($columns) {
                return new TableRow($model, $this, $columns);
            })
            ->each(function (TableRow $tableRow): void {
                $this->data[] = $tableRow;
            });

        return $this;
    }
}
