<?php

namespace EventPortal\Tests\Feature\Admin\Permission;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Tests\Support\Traits\InteractsWithTeams;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class PermissionMiddlewareTest extends TestCase
{
    use RefreshDatabase, InteractsWithTeams;

    /** @test **/
    public function event_show()
    {
        $event = factory(Event::class)->state('has-team')->create();
        $admin = factory(Admin::class)->create();

        $this->addToSameTeam([$admin, $event], $event->teams()->first());

        $permission = factory(Permission::class)->create([
            'name' => 'event.show',
        ]);

        $admin->givePermissionTo($permission);

        $this
            ->actingAsAdmin($admin)
            ->get(route('admin.event.show', $event))
            ->assertOk();
    }

    /** @test **/
    public function event_store()
    {
        $event = factory(Event::class)->state('has-team')->create();
        $admin = factory(Admin::class)->create();

        $this->addToSameTeam([$admin, $event], $event->teams()->first());

        $permission = factory(Permission::class)->create([
            'name' => 'event.store',
        ]);

        $admin->givePermissionTo($permission);

        $this
            ->actingAsAdmin($admin)
            ->get(route('admin.event.create', $event))
            ->assertOk();

        // Validation varies per client, so just assert the user is authorised to post to this endpoint
        $response = $this
            ->actingAsAdmin($admin)
            ->post(route('admin.event.store', $event));

        $this->assertNotEquals(401, $response->getStatusCode());
    }

    /** @test **/
    public function event_update()
    {
        $event = factory(Event::class)->state('has-team')->create();
        $admin = factory(Admin::class)->create();

        $this->addToSameTeam([$admin, $event], $event->teams()->first());

        $permission = factory(Permission::class)->create([
            'name' => 'event.update',
        ]);

        $admin->givePermissionTo($permission->id);

        $this
            ->actingAsAdmin($admin)
            ->get(route('admin.event.edit', $event))
            ->assertOk();

        // Validation varies per client, so just assert the user is authorised to post to this endpoint
        $response = $this
            ->actingAsAdmin($admin)
            ->post(route('admin.event.update', $event));

        $this->assertNotEquals(401, $response->getStatusCode());
    }

    /** @test **/
    public function event_destroy()
    {
        factory(Permission::class)->create(['name' => 'event.create']);
        $event = factory(Event::class)->state('has-team')->create();
        $admin = factory(Admin::class)->create();

        $this->addToSameTeam([$admin, $event], $event->teams()->first());

        $permission = factory(Permission::class)->create([
            'name' => 'event.destroy',
        ]);

        $admin->givePermissionTo($permission->id);

        $this->withoutExceptionHandling();

        $this
            ->actingAsAdmin($admin)
            ->followingRedirects()
            ->post(route('admin.event.delete', $event))
            ->assertOk();
    }
}
