<?php

namespace EventPortal\Tests\Feature\Admin\Speaker;

use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class SpeakerCreateTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_create_a_speaker(): void
    {
        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.speaker.store'), [
                'first_name' => 'Firstname',
                'last_name' => 'Lastname',
                'email' => 'test@example.com',
                'profession' => 'Teacher',
                'telephone_number' => '01234567890',
            ])
            ->assertOk();

        $this->assertEquals(route('admin.speaker.show', 1), url()->current());

        $speaker = Speaker::first();
        $this->assertEquals('Firstname Lastname', $speaker->name);
        $this->assertEquals('test@example.com', $speaker->user->email);
        $this->assertEquals('Teacher', $speaker->profession);
        $this->assertEquals('01234567890', $speaker->telephone_number);
    }
}
