<?php

namespace EventPortal\Tests\Feature\Admin\Speaker;

use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class SpeakerUpdateTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_update_speaker(): void
    {
        $user = factory(User::class)->create([
            'first_name' => 'Original Firstname',
            'last_name' => 'Original Lastname',
            'email' => 'original@example.com',
        ]);
        $speaker = factory(Speaker::class)->create([
            'profession' => 'Original Teacher',
            'telephone_number' => '11111111111',
            'user_id' => $user->id,
        ]);

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.speaker.update', $speaker), [
                'first_name' => 'Firstname',
                'last_name' => 'Lastname',
                'email' => 'test@example.com',
                'profession' => 'Teacher',
                'telephone_number' => '01234567890',
            ])
            ->assertOk();

        $newSpeaker = Speaker::first();
        $this->assertEquals('Firstname Lastname', $newSpeaker->name);
        $this->assertEquals('test@example.com', $newSpeaker->user->email);
        $this->assertEquals('Teacher', $newSpeaker->profession);
        $this->assertEquals('01234567890', $newSpeaker->telephone_number);
    }
}
