<?php

namespace EventPortal\Tests\Unit\Component;

use EventPortal\Domain\Component\Option;
use EventPortal\Tests\TestCase;

class OptionTest extends TestCase
{
    /** @test **/
    public function can_make_without_giving_value()
    {
        $selectValue = Option::make('Seminar');

        $this->assertEquals('Seminar', $selectValue->label);
        $this->assertEquals('seminar', $selectValue->value);
    }

    /** @test **/
    public function can_make_with_giving_value()
    {
        $selectValue = Option::make('Seminar')->value('waffle');

        $this->assertEquals('Seminar', $selectValue->label);
        $this->assertEquals('waffle', $selectValue->value);
    }

    /** @test **/
    public function can_make_with_giving_integer_value()
    {
        $selectValue = Option::make('Seminar')->value(2);

        $this->assertEquals('Seminar', $selectValue->label);
        $this->assertEquals(2, $selectValue->value);
    }

    /** @test **/
    public function value_defaults_to_slugged()
    {
        $selectValue = Option::make('Hello World');

        $this->assertEquals('hello_world', $selectValue->value);
    }

    /** @test **/
    public function can_provide_alternative_seperator()
    {
        $selectValue = Option::make('Hello World', '-');

        $this->assertEquals('hello-world', $selectValue->value);
    }

    /** @test **/
    public function can_get_as_json()
    {
        $optionAsJson = Option::make('Seminar')->value('seminar')->toJson();

        $expected = ['label' => 'Seminar', 'value' => 'seminar'];

        $this->assertEquals(json_encode($expected), $optionAsJson);
    }
}
